@@ -1197,8 +1197,7 @@ class LaharFlowData(object):
 
         if crs is not None:
             if crs != wgs84:
-                for j, r in enumerate(raster):
-                    r.rio.reproject(crs, inplace=True)
+                raster.rio.reproject(crs, inplace=True)
 
         if fileOut is None:
             fname, fext = os.path.splitext(fileIn)
